# WIP

The plan is to rewrite [bloghead](https://github.com/nhanb/bloghead) but this
time as a proper Qt application. Nothing but the mockup UI has been done yet.

![](mockup.png)

# Dependencies

Assumes nodejs (command `node`) is available in $PATH.
